@@ -1,5 +1,5 @@
 `baseline` <-
-function(spect, init.bd, sm.par = 1e-11, sm.ord = 2, max.iter = 40, tol = 5e-8,
+function(spect, init.bd, sm.par = 1e-11, sm.ord = 2, max.iter = 20, tol = 5e-8,
          sm.div = NA, sm.norm.by = c("baseline", "overestimate", "constant"),
          neg.div = NA, neg.norm.by = c("baseline", "overestimate", "constant"),
          rel.conv.crit = TRUE, zero.rm = TRUE, halve.search = FALSE){
@@ -19,9 +19,9 @@ function(spect, init.bd, sm.par = 1e-11, sm.ord = 2, max.iter = 40, tol = 5e-8,
             }
         }
     }
-    neg.norm.by <- substr(neg.norm.by[1],1,1)
-    sm.norm.by <- substr(sm.norm.by[1],1,1)
-    if(sm.norm.by == "c" || neg.norm.by == "c"){
+    neg.norm.by <- match.arg(neg.norm.by)
+    sm.norm.by <- match.arg(sm.norm.by)
+    if(sm.norm.by == "constant" || neg.norm.by == "constant"){
         bin.ends <- round((0:1024)/1024 * L)
         ss <- sapply(1:1024, function(x){
             .biweight.FTICRMS(spect[(bin.ends[x]+1):bin.ends[x+1]], K=9)$scale/qnorm(0.75)
@@ -30,16 +30,16 @@ function(spect, init.bd, sm.par = 1e-11, sm.ord = 2, max.iter = 40, tol = 5e-8,
     }
     if(is.na(sm.div)){
         sm.div <- switch(sm.norm.by,
-            b = 0.5223145,
-            o = 1,
-            c = ss)
-        sm.fact <- L^(2*sm.ord)*sm.par/sm.div
+            baseline = 0.5223145,
+            overestimate = 1,
+            constant = ss)
     }
+    sm.fact <- L^(2*sm.ord)*sm.par/sm.div
     if(is.na(neg.div)){
         neg.div <- switch(neg.norm.by,
-            b = 0.4210109,
-            o = 1,
-            c = ss/sqrt(pi/2))
+            baseline = 0.4210109,
+            overestimate = 1,
+            constant = ss/sqrt(pi/2))
     }
 
     if(missing(init.bd)){
@@ -60,7 +60,7 @@ function(spect, init.bd, sm.par = 1e-11, sm.ord = 2, max.iter = 40, tol = 5e-8,
             p = as.integer(cumsum(c(0,rep(2,L1)))),
             x = as.numeric(c(-1,-0.5, 1, rep(c(-0.5,0.5), L1-3), -1,0.5,1))) %*% M
     }
-    if(sm.norm.by == "c"){
+    if(sm.norm.by == "constant"){
         Mtmp <- sm.fact * crossprod(M)
         rm(M)
         tmpgc <- ""
@@ -87,26 +87,26 @@ function(spect, init.bd, sm.par = 1e-11, sm.ord = 2, max.iter = 40, tol = 5e-8,
         indicator0 <- indicator
         bd0 <- bd
 
-        if(sm.norm.by == "b"){
+        if(sm.norm.by == "baseline"){
             Mtmp <- crossprod(new("dsCMatrix", Dim=as.integer(c(L1,L1)), 
                 x=as.numeric(sqrt(sm.fact/bd[floor(1+(L-L1)/2):floor((L+L1)/2)])),
                 p=as.integer(0:L1), i=as.integer(0:(L1-1))) %*% M)
-        } else if (sm.norm.by == "o"){
+        } else if (sm.norm.by == "overestimate"){
             Mtmp <- crossprod(new("dsCMatrix", Dim=as.integer(c(L1,L1)), 
                 x=as.numeric(sqrt(sm.fact/ 
                     ifelse(bd > spect, as.numeric(bd-spect), 1)[floor(1+(L-L1)/2):floor((L+L1)/2)])),
                 p=as.integer(0:L1), i=as.integer(0:(L1-1))) %*% M)
         }
-        if(neg.norm.by == "b"){
+        if(neg.norm.by == "baseline"){
             B <- Mtmp %*% bd - 1/2 + ifelse(is.na(spect), 0, as.numeric((bd-spect) * indicator/bd/neg.div))
             M1 <- Mtmp + new("dsCMatrix", Dim=as.integer(c(L,L)), 
                 x=as.numeric(indicator/bd/neg.div), p=as.integer(0:L), i=as.integer(0:(L-1)))
-        } else if (neg.norm.by == "o"){
+        } else if (neg.norm.by == "overestimate"){
             B <- Mtmp %*% bd - 1/2 + ifelse(is.na(spect), 0, as.numeric(indicator/neg.div))
             M1 <- Mtmp + new("dsCMatrix", Dim=as.integer(c(L,L)), 
                 x=as.numeric(indicator / neg.div / ifelse(as.numeric(bd) > spect, as.numeric(bd-spect), 1)),
                 p=as.integer(0:L), i=as.integer(0:(L-1)))
-        } else if(neg.norm.by == "c"){
+        } else if(neg.norm.by == "constant"){
             M1 <- Mtmp + new("dsCMatrix", Dim=as.integer(c(L,L)), 
                 x=as.numeric(indicator/neg.div), p=as.integer(0:L), i=as.integer(0:(L-1)))
             B <- Mtmp %*% bd - 1/2 + ifelse(is.na(spect), 0, as.numeric((bd-spect) * indicator/neg.div))
